@@ -1,6 +1,222 @@
+from typing import Dict, Tuple
+from ipaddress import IPv4Network, IPv4Address
+
+from .errors import GeneralError
+
+
+# Regional Internet Registry IPv4 Allocations:
+# https://www.iana.org/assignments/ipv4-address-space/ipv4-address-space.xhtml
+# and https://data.iana.org/rdap/ipv4.json
+class IPv4Allocations:
+    _allocations: Dict[IPv4Network, Dict[str, str]] = {
+        IPv4Network('1.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('2.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('3.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('4.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('5.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('6.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('7.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('8.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('9.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('11.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('12.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('13.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('14.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('15.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('16.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('17.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('18.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('19.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('20.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('21.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('22.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('23.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('24.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('25.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('26.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('27.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('28.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('29.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('30.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('31.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('32.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('33.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('34.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('35.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('36.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('37.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('38.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('39.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('40.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('41.0.0.0/8'): {'rdap':'https://rdap.afrinic.net/rdap/','whois':'whois.afrinic.net'},
+        IPv4Network('42.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('43.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('44.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('45.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('46.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('47.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('48.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('49.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('50.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('51.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('52.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('53.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('54.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('55.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('56.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('57.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('58.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('59.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('60.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('61.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('62.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('63.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('64.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('65.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('66.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('67.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('68.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('69.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('70.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('71.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('72.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('73.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('74.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('75.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('76.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('77.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('78.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('79.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('80.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('81.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('82.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('83.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('84.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('85.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('86.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('87.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('88.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('89.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('90.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('91.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('92.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('93.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('94.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('95.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('96.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('97.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('98.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('99.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('100.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('101.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('102.0.0.0/8'): {'rdap':'https://rdap.afrinic.net/rdap/','whois':'whois.afrinic.net'},
+        IPv4Network('103.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('104.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('105.0.0.0/8'): {'rdap':'https://rdap.afrinic.net/rdap/','whois':'whois.afrinic.net'},
+        IPv4Network('106.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('107.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('108.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('109.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('110.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('111.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('112.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('113.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('114.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('115.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('116.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('117.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('118.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('119.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('120.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('121.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('122.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('123.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('124.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('125.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('126.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('128.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('129.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('130.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('131.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('132.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('133.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('134.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('135.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('136.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('137.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('138.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('139.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('140.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('141.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('142.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('143.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('144.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('145.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('146.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('147.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('148.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('149.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('150.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('151.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('152.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('153.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('154.0.0.0/8'): {'rdap':'https://rdap.afrinic.net/rdap/','whois':'whois.afrinic.net'},
+        IPv4Network('155.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('156.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('157.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('158.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('159.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('160.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('161.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('162.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('163.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('164.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('165.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('166.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('167.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('168.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('169.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('170.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('171.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('172.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('173.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('174.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('175.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('176.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('177.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('178.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('179.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('180.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('181.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('182.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('183.0.0.0/8'): {'rdap':'https://rdap.apnic.net/','whois':'whois.apnic.net'},
+        IPv4Network('184.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('185.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('186.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('187.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('188.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('189.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('190.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('191.0.0.0/8'): {'rdap':'https://rdap.lacnic.net/rdap/','whois':'whois.lacnic.net'},
+        IPv4Network('192.0.0.0/8'): {'rdap':'https://rdap.arin.net/registry','whois':'whois.arin.net'},
+        IPv4Network('193.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('194.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+        IPv4Network('195.0.0.0/8'): {'rdap':'https://rdap.db.ripe.net/','whois':'whois.ripe.net'},
+    }
+    
+    def get_servers(self, ipv4: IPv4Address) -> Tuple[str, str]:
+        """
+        Retrieves the WHOIS and RDAP servers for the given IPv4 address.
+        """
+        for network, servers in self._allocations.items():
+            if ipv4 in network:
+                return servers['rdap'], servers['whois']
+        # no match
+        raise GeneralError(f'No WHOIS or RDAP server for: {ipv4}')
+
+
 # Top Level Domain WHOIS Server Names
 # Retrieved from https://www.iana.org/domains/root/db
-# This file was last updated on 2021-06-12
 
 class CountryCodeTLD:
     AC = 'whois.nic.ac'
